@@ -24,7 +24,7 @@
 import click
 
 from datetime import datetime
-from web3 import Web3
+# from web3 import Web3
 
 from blockchainetl.file_utils import smart_open
 from blockchainetl.logging_utils import logging_basic_config
@@ -47,8 +47,8 @@ def get_block_range_for_date(provider_uri, date, output, chain='ethereum'):
     """Outputs start and end blocks for given date."""
     provider_uri = check_classic_provider_uri(chain, provider_uri)
     provider = get_provider_from_uri(provider_uri)
-    web3 = Web3(provider)
-    theta_service = ThetaService(web3)
+    # web3 = Web3(provider)
+    theta_service = ThetaService(provider)
 
     start_block, end_block = theta_service.get_block_range_for_date(date)
 
